"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_i_1 = require("fs-i");
const path = require("path");
const readProjectConfig_1 = require("../tools/readProjectConfig");
const nodeBuilder_1 = require("./build/nodeBuilder");
const log_1 = require("../common/log");
const const_1 = require("../common/const");
exports.command = "build";
exports.desc = "构建项目";
exports.builder = (yargs) => {
    return yargs
        .option("p", {
        alias: "path",
        describe: "构建的目录",
        default: ".",
        type: "string"
    })
        .usage("Usage: $0 build -p .");
};
exports.handler = (yargs) => __awaiter(this, void 0, void 0, function* () {
    log_1.printMessage("构建开始...");
    try {
        let builder = null;
        let projectPath = path.resolve(yargs.p) || process.cwd();
        let configFileName = path.join(projectPath, const_1.projectConfigFile);
        let projectConfig = yield readProjectConfig_1.readProjectConfig(configFileName);
        fs_i_1.rmdirSync(path.join(projectPath, "./lib"));
        fs_i_1.rmdirSync(path.join(projectPath, "./es"));
        fs_i_1.rmdirSync(path.join(projectPath, "./docs"));
        switch (projectConfig.projectType) {
            case "node":
                builder = new nodeBuilder_1.NodeBuilder();
                break;
        }
        yield builder.run(projectPath, projectConfig);
        log_1.printSuccessMessage("构建完成");
    }
    catch (e) {
        log_1.printErrorMessage(`${e}\n构建失败！`);
    }
});
//# sourceMappingURL=build.js.map