"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const baseProj_1 = require("./baseProj");
const fs_i_1 = require("fs-i");
const globalData_1 = require("../../../model/globalData");
const path = require("path");
const zip_i_1 = require("zip-i");
const util_1 = require("../../../common/util");
const fs_1 = require("fs");
const template_1 = require("../../../common/template");
class NodeProj extends baseProj_1.BaseProj {
    getQuestions() {
        let questionList = [
            {
                name: "needDocs",
                type: "list",
                message: "是否需要有开发文档",
                default: "否",
                choices: ["是", "否"]
            },
            {
                name: "unittest",
                type: "list",
                message: "是否需要创建单元测试？",
                default: "否",
                choices: ["是", "否"]
            },
            {
                name: "isCommand",
                type: "list",
                message: "是否创建命令？",
                default: "否",
                choices: ["是", "否"]
            }
        ];
        return questionList;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            let answer = yield this.getAnswers();
            let templateZipFile = template_1.TemplateData.getProjectTemplate("node.zip");
            yield zip_i_1.unzipPath(templateZipFile, globalData_1.GlobalData.projectRootPath);
            if (answer.needDocs === "是") {
                this.addDocs();
            }
            if (answer.unittest === "是") {
                this.addUnitTest();
            }
        });
    }
    addDocs() {
        return __awaiter(this, void 0, void 0, function* () {
            yield util_1.editPackageJson(globalData_1.GlobalData.projectRootPath, json => {
            });
        });
    }
    addUnitTest() {
        return __awaiter(this, void 0, void 0, function* () {
            yield util_1.editPackageJson(globalData_1.GlobalData.projectRootPath, json => {
                Object.assign(json.devDependencies, {
                    "@types/chai": "^4.0.5",
                    chai: "^4.1.2",
                    "@types/mocha": "^2.2.44",
                    mocha: "^4.0.1",
                });
            });
            {
                yield util_1.editFile(path.join(globalData_1.GlobalData.projectRootPath, ".travis.yml"), fileContent => {
                    fileContent = fileContent.replace(/\nscript\s*:/, (w, a, b, c, d) => {
                        return (w +
                            `
  - pcreate test`);
                    });
                    fileContent = fileContent.replace(/deploy\s*:/, (w, a, b, c, d) => {
                        return (w +
                            `
  - provider: pages
    skip_cleanup: true
    github_token: $GITHUB_TOKEN
    local_dir: docs
    on:
      branch: master
  `);
                    });
                    return fileContent;
                });
            }
            {
                let testPath = path.join(globalData_1.GlobalData.projectRootPath, "test");
                yield fs_i_1.mkdirs(testPath);
                fs_1.writeFileSync(path.join(testPath, "mocha.opts"), `
--require ts-node/register
--require source-map-support/register
--full-trace
--bail
test/**/*.test.ts
        `.trim());
                fs_1.writeFileSync(path.join(testPath, "index.test.ts"), `
import { expect } from "chai";
import "mocha";
import { add } from "../src/index";

describe("index", function() {
  before(async () => {});
  after(async () => {});

  it("add should be success", async () => {
    expect(add(1, 2)).to.equal(3);
  });
});   
      `.trim());
            }
        });
    }
}
exports.NodeProj = NodeProj;
//# sourceMappingURL=nodeProj.js.map