"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const readProjectConfig_1 = require("../tools/readProjectConfig");
const log_1 = require("../common/log");
const const_1 = require("../common/const");
const util_1 = require("../common/util");
const child_process_1 = require("child_process");
const fs_1 = require("fs");
exports.command = "test";
exports.desc = "单元测试";
exports.builder = (yargs) => {
    return yargs
        .option("p", {
        alias: "path",
        describe: "测试的目录",
        default: ".",
        type: "string"
    })
        .usage("Usage: $0 test -p .");
};
exports.handler = (yargs) => __awaiter(this, void 0, void 0, function* () {
    let projectPath = path.resolve(yargs.p) || process.cwd();
    let configFileName = path.join(projectPath, const_1.projectConfigFile);
    let projectConfig = yield readProjectConfig_1.readProjectConfig(configFileName);
    if (projectConfig.unitTest) {
        let mochapars = yargs.mochapars;
        test(projectPath, mochapars);
        coveralls(projectPath, mochapars);
    }
});
function test(projectPath, mochapars) {
    log_1.printMessage("单元测试开始...");
    let nyc = util_1.getCreateProjectDependencies(projectPath, path.join("nyc", "bin", "nyc.js"));
    let mocha = util_1.getCreateProjectDependencies(projectPath, path.join("mocha", "bin", "mocha"));
    let pars = [];
    if (mochapars) {
        mochapars = `{${mochapars
            .replace(/[\"\'\{\}]/g, "")
            .split(",")
            .map(h => `"${h.replace(/:/g, '":"')}"`)
            .join(",")}}`;
        let mochaparsObj = JSON.parse(mochapars);
        for (let k of Reflect.ownKeys(mochaparsObj)) {
            pars.push(`--${k}`);
            pars.push(Reflect.get(mochaparsObj, k));
        }
    }
    let options = {
        encoding: "utf8",
        cwd: projectPath,
        stdio: [process.stdin, process.stdout, process.stderr]
    };
    let childProcess = child_process_1.spawnSync(nyc, [mocha, "-t", "5000"].concat(pars), options);
    if (childProcess.status !== 0) {
        log_1.printErrorMessage(childProcess.error.message);
        log_1.printErrorMessage("单元测试失败！");
        process.exit(childProcess.status);
        return;
    }
    log_1.printMessage("单元测试成功结束");
}
function coveralls(projectPath, mochapars) {
    log_1.printMessage("覆盖率开始...");
    let nycrcFile = path.join(projectPath, ".nycrc");
    fs_1.writeFileSync(nycrcFile, `{
  "include": [
    "src/**/*.ts"
  ],
  "extension": [
    ".ts"
  ],
  "require": [
    "ts-node/register"
  ],
  "sourceMap": true,
  "instrument": true
}`.trim());
    let nyc = util_1.getCreateProjectDependencies(projectPath, path.join("nyc", "bin", "nyc.js"));
    let coveralls = util_1.getCreateProjectDependencies(projectPath, path.join("coveralls", "bin", "coveralls.js"));
    let commandText = `"${nyc}" mocha -t 5000 && "${nyc}" report --reporter=text-lcov | "${coveralls}"`;
    let res = child_process_1.execSync(commandText, { encoding: "utf-8", cwd: projectPath });
    fs_1.unlinkSync(nycrcFile);
    log_1.printMessage("覆盖率完成");
}
//# sourceMappingURL=test.js.map