"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const asyncExec_1 = require("../tools/asyncExec");
const path = require("path");
const fs_1 = require("fs");
const lodash_1 = require("lodash");
function compile(projectPath, projectConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        let compile = projectConfig.compile;
        if (!compile) {
            return;
        }
        if (lodash_1.isArray(compile)) {
            for (let c of compile) {
                yield compileWithCompileModel(c, projectConfig.sourceInclude, projectPath);
            }
        }
        else if (lodash_1.isObject(compile)) {
            yield compileWithCompileModel(compile, projectConfig.sourceInclude, projectPath);
        }
    });
}
exports.compile = compile;
function compileWithCompileModel(compile, sourceInclude, projectPath) {
    return __awaiter(this, void 0, void 0, function* () {
        let json = {
            compilerOptions: {
                outDir: compile.outDir,
                target: compile.target,
                module: compile.module,
                allowJs: compile.allowJs,
                declaration: compile.declaration,
                sourceMap: compile.sourceMap,
                noImplicitAny: compile.noImplicitAny,
                removeComments: true,
                lib: ["ESNEXT"],
                types: ["node"]
            },
            include: sourceInclude
        };
        let tsConfigFile = path.join(projectPath, `tsconfig.json`);
        let tsConfigText = JSON.stringify(json, null, 2);
        fs_1.writeFileSync(tsConfigFile, tsConfigText);
        console.log(tsConfigFile);
        console.log(tsConfigText);
        yield asyncExec_1.asyncExec("tsc", ["-p", 'tsconfig.json']);
        fs_1.unlinkSync(tsConfigFile);
    });
}
//# sourceMappingURL=tsc.js.map